local L = LibStub("AceLocale-3.0"):GetLocale("ShockAndAwe")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");

ShockAndAwe.PriorityFrame = CreateFrame("Frame", "SAA_PriorityFrame", UIParent)

---------------------------
-- Local Variables
---------------------------

-- constants
ShockAndAwe.priorityType = {}
ShockAndAwe.priorityType.MW5_LB = "mw5_lb"
ShockAndAwe.priorityType.MW5_CL = "mw5_cl"
ShockAndAwe.priorityType.SS = "ss"
ShockAndAwe.priorityType.ES = "es"
ShockAndAwe.priorityType.FS = "fs"
ShockAndAwe.priorityType.LL = "ll"

ShockAndAwe.priorityTable = {}
ShockAndAwe.priorityTable.name = {}
ShockAndAwe.priorityTable.icon = {}
ShockAndAwe.priorityTable.name["mw5_lb"] = L["MW5 Lightning Bolt"]
_, _, ShockAndAwe.priorityTable.icon["mw5_lb"] = GetSpellInfo(49238)
ShockAndAwe.priorityTable.name["mw5_cl"] = L["MW5 Chain Lightning"]
_, _, ShockAndAwe.priorityTable.icon["mw5_cl"] = GetSpellInfo(49269)
ShockAndAwe.priorityTable.name["ss"] = L["Stormstrike"]
_, _, ShockAndAwe.priorityTable.icon["ss"] = GetSpellInfo(17364)
ShockAndAwe.priorityTable.name["es"] = L["Earth Shock"]
_, _, ShockAndAwe.priorityTable.icon["es"] = GetSpellInfo(49231)
ShockAndAwe.priorityTable.name["fs"] = L["Flame Shock"]
_, _, ShockAndAwe.priorityTable.icon["fs"] = GetSpellInfo(49233)
ShockAndAwe.priorityTable.name["ll"] = L["Lava Lash"]
_, _, ShockAndAwe.priorityTable.icon["ll"] = GetSpellInfo(60103)
ShockAndAwe.priorityTable.name["none"] = L["none"]
_, _, ShockAndAwe.priorityTable.icon["none"] = "Interface/Tooltips/UI-Tooltip-Background"

---------------------------
-- Priority Frame functions
---------------------------

function ShockAndAwe:CreatePriorityFrame()
	self.PriorityFrame:SetScale(self.db.char.priority.scale)
	self.PriorityFrame:SetFrameStrata("BACKGROUND")
	self.PriorityFrame:SetWidth(self.db.char.priority.fWidth)
	self.PriorityFrame:SetHeight(self.db.char.priority.fHeight)
	self.PriorityFrame:SetBackdrop({
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	})
	self.PriorityFrame:SetBackdropColor(0, 0, 0, self.db.char.priority.alpha);
	self.PriorityFrame:SetMovable(true);
	self.PriorityFrame:RegisterForDrag("LeftButton");
	self.PriorityFrame:SetPoint(self.db.char.priority.point, self.db.char.priority.relativeTo, self.db.char.priority.relativePoint, self.db.char.priority.xOffset, self.db.char.priority.yOffset)
	self.PriorityFrame:SetScript("OnDragStart", 
		function()
			self.PriorityFrame:StartMoving();
		end );
	self.PriorityFrame:SetScript("OnDragStop",
		function()
			self.PriorityFrame:StopMovingOrSizing();
			self.PriorityFrame:SetScript("OnUpdate", nil);
			self:FinishedMoving(self.db.char.priority, self.PriorityFrame);
		end );
		
	if not self.PriorityFrame.topText then
		self.PriorityFrame.topText = self.PriorityFrame:CreateFontString(nil, "OVERLAY")
	end
	self.PriorityFrame.topText:SetTextColor(1,1,1,1)
	self.PriorityFrame.topText:SetFont(media:Fetch("font", self.db.char.barfont), self.db.char.barfontsize)
	self.PriorityFrame.topText:SetPoint("TOP", self.PriorityFrame, "TOP", 0, self.db.char.barfontsize + 2)
	self.PriorityFrame.topText:SetText(L["Next Priority"])

	if self.db.char.priority.show then
		self.PriorityFrame:Show()
	else
		self.PriorityFrame:Hide()
	end
end

function ShockAndAwe:ResetPriority()
	self.PriorityFrame:ClearAllPoints()
	self.db.char.Priority.point = defaults.char.priority.point
	self.db.char.priority.relativeTo = defaults.char.priority.relativeTo 
	self.db.char.priority.relativePoint = defaults.char.priority.relativePoint
	self.db.char.priority.xOffset = defaults.char.priority.xOffset
	self.db.char.priority.yOffset = defaults.char.priority.yOffset
	self.db.char.priority.fWidth = defaults.char.priority.fWidth
	self.db.char.priority.fHeight = defaults.char.priority.fHeight
	self.db.char.priority.scale = defaults.char.priority.scale
	self.PriorityFrame:SetPoint(self.db.char.priority.point, self.db.char.priority.relativeTo, self.db.char.priority.relativePoint, self.db.char.priority.xOffset, self.db.char.priority.yOffset)
	self:CreatePriorityFrame()
	self.db.char.barshow = true -- so that call to ShowHideBars resets to false
	self:ShowHideBars()
	self:Print(L["priority_reset"])
end
